@@ -238,7 +238,7 @@ impl FromStr for Query {
     type Err = anyhow::Error;
 
     fn from_str(s: &str) -> Result<Self, Self::Err> {
-        let sexp = lexpr::from_str(s)?;
+        let sexp = lexpr::from_str_custom(s, lexpr::parse::Options::new())?;
         Query::try_from(&sexp)
     }
 }
