@@ -2,7 +2,7 @@ use std::borrow::Borrow;
 use std::convert::TryFrom;
 use std::path::{Component, Path, PathBuf};
 use std::sync::{Arc, Mutex, RwLock};
-use std::time::{Instant, UNIX_EPOCH};
+use std::time::{Instant, SystemTime, UNIX_EPOCH};
 use std::{fs, iter};
 
 use crate::addressing::Address;
@@ -410,6 +410,17 @@ fn insert_file_with_metadata(
         value: EntryValue::String(mime_type),
     });
 
+    let added_entry = Entry {
+        entity: Address::Hash(hash.clone()),
+        attribute: "ADDED".to_string(),
+        value: EntryValue::Number(
+            SystemTime::now()
+                .duration_since(UNIX_EPOCH)
+                .unwrap()
+                .as_secs() as f64,
+        ),
+    };
+
     // Add the appropriate entries w/r/t virtual filesystem location
     let components = normalized_path.components().collect::<Vec<Component>>();
     let (filename, dir_path) = components.split_last().unwrap();
@@ -429,10 +440,13 @@ fn insert_file_with_metadata(
 
     // Insert all
     connection.transaction::<_, Error, _>(|| {
-        connection.insert_file(new_file)?;
+        let file_count = connection.insert_file(new_file)?;
 
         connection.insert_entry_immutable(type_entry)?;
         connection.insert_entry_immutable(size_entry)?;
+        if file_count == 1 {
+            connection.insert_entry_immutable(added_entry)?;
+        }
         if let Some(mime_entry) = mime_entry {
             connection.insert_entry(mime_entry)?;
         }
