@@ -216,7 +216,11 @@ fn main() -> Result<()> {
 
     if !matches.is_present("NO_INITIAL_UPDATE") {
         info!("Running initial update...");
-        actix::spawn(filesystem::rescan_vault(upend, job_container, false, true));
+        if open_result.new {
+            actix::spawn(filesystem::rescan_vault(upend, job_container, false, true));
+        } else {
+            actix::spawn(filesystem::rescan_vault(upend, job_container, true, false));
+        }
     }
 
     #[cfg(feature = "desktop")]
