@@ -38,7 +38,7 @@ export function query(query: () => string) {
   const queryString = typeof query === "string" ? query : query();
   console.debug(`Querying: ${queryString}`);
   const { data, error, revalidate } = useSWR<ListingResult, unknown>(
-    () => `/api/obj?query=${query()}`
+    () => `/api/obj?query=${encodeURIComponent(query())}`
   );
 
   const result = derived(data, ($values) => {
