@@ -15,7 +15,12 @@ export function useSWR<D = unknown, E = Error>(
       if (response.ok) {
         data.set(await response.json());
       } else {
-        throw new Error(await response.json());
+        let errorText = `${response.status} ${response.statusText}`;
+        const responseText = await response.text();
+        if (responseText) {
+          errorText += ` - ${responseText}`;
+        }
+        throw new Error(errorText);
       }
     } catch (err) {
       error.set(err);
